@@ -28,6 +28,7 @@ const { GLib, Gio, Meta, Shell } = imports.gi;
 const Main = imports.ui.main;
 const ExtensionUtils = imports.misc.extensionUtils;
 const ExtensionSystem = imports.ui.extensionSystem;
+const UnlockDialog = imports.ui.unlockDialog;
 
 const Extension = ExtensionUtils.getCurrentExtension();
 const Config = Extension.imports.config;
@@ -68,6 +69,7 @@ var PomodoroExtension = class {
         this._isPaused           = false;
         this._timerState         = Timer.State.NULL;
         this._timerStateDuration = 0.0;
+        this._notificationsBoxPatch = null;
 
         try {
             this.settings = Settings.getSettings('org.gnome.pomodoro.preferences');
@@ -106,12 +108,12 @@ var PomodoroExtension = class {
     setMode(mode) {
         if (!this.service.initialized) {
             this.mode = mode;
-            this._isModePending = true;
+            this._isModePending = true;  // TODO: make setMode async instead of using _isModePending
 
             return;  /* wait until service name is acquired */
         }
 
-        if (this.mode != mode || this._isModePending) {
+        if (this.mode !== mode || this._isModePending) {
             this.mode = mode;
             this._isModePending = false;
 
@@ -135,6 +137,7 @@ var PomodoroExtension = class {
             }
 
             this._enableKeybinding();
+            this._enableScreenShieldWidget();
             this._updateNotification();
         }
     }
@@ -248,20 +251,22 @@ var PomodoroExtension = class {
 
             this._destroyPreviousNotifications();
         }
+
+        Utils.wakeUpScreen();
     }
 
-    _notifyPomodoroEnd() {
-        if (this.notification &&
-            this.notification instanceof Notifications.PomodoroEndNotification)
-        {
-            if (this.dialog && this.timer.isBreak()) {
-                this.dialog.open(true);
-            }
-            else if (this.notification.resident || this.notification.acknowledged) {
-                this.notification.show();
-            }
+    async _notifyPomodoroEndAsync() {
+        let canOpenDialog;
+        try {
+            canOpenDialog = this.dialog && await this.dialog.canOpenAsync();
         }
-        else {
+        catch (error) {
+            canOpenDialog = false;
+        }
+
+        if (!this.notification ||
+            !(this.notification instanceof Notifications.PomodoroEndNotification))
+        {
             this.notification = new Notifications.PomodoroEndNotification(this.timer);
             this.notification.connect('activated',
                 (notification) => {
@@ -277,23 +282,29 @@ var PomodoroExtension = class {
                 });
             this.notification.connect('destroy', this._onNotificationDestroy.bind(this));
 
-            if (this.dialog && this.timer.isBreak()) {
-                this.dialog.open(true);
-            }
-            else {
-                this.notification.show();
-            }
-
             this._destroyPreviousNotifications();
         }
+
+        if (canOpenDialog) {
+            this.dialog.open(true);
+        }
+        else {
+            this.notification.show();
+        }
+
+        Utils.wakeUpScreen();
+    }
+
+    _notifyPomodoroEnd() {
+        this._notifyPomodoroEndAsync();
     }
 
     _updateNotification() {
         let timerState = this.timer.getState();
         let isPaused   = this.timer.isPaused();
 
-        if (timerState != Timer.State.NULL && (!isPaused || this.timer.getElapsed() == 0.0)) {
-            if (this.mode == ExtensionMode.RESTRICTED) {
+        if (timerState !== Timer.State.NULL && (!isPaused || this.timer.getElapsed() == 0.0)) {
+            if (this.mode === ExtensionMode.RESTRICTED) {
                 this._destroyNotifications();
 
                 let idleId = GLib.idle_add(GLib.PRIORITY_DEFAULT, () => {
@@ -305,7 +316,7 @@ var PomodoroExtension = class {
                                            '[gnome-pomodoro] this._updateScreenShieldNotification');
             }
             else if (this.timer.getRemaining() > NOTIFICATIONS_TIME_OFFSET) {
-                if (timerState == Timer.State.POMODORO) {
+                if (timerState === Timer.State.POMODORO) {
                     this._notifyPomodoroStart();
                 }
                 else {
@@ -313,7 +324,7 @@ var PomodoroExtension = class {
                 }
             }
             else {
-                if (timerState != Timer.State.POMODORO) {
+                if (timerState !== Timer.State.POMODORO) {
                     this._notifyPomodoroStart();
                 }
                 else {
@@ -326,18 +337,33 @@ var PomodoroExtension = class {
         }
     }
 
-    _updateScreenNotification() {
+    async _updateScreenNotificationAsync(animate) {
         if (this.dialog) {
-            if (this.timer.isBreak() && !this.timer.isPaused()) {
-                this.dialog.open(false);
+            let canOpenDialog = true;
+
+            if (animate) {
+                try {
+                    canOpenDialog = await this.dialog.canOpenAsync();
+                }
+                catch (error) {
+                    canOpenDialog = false;
+                }
+            }
+
+            if (this.timer.isBreak() && !this.timer.isPaused() && canOpenDialog) {
+                this.dialog.open(animate);
                 this.dialog.pushModal();
             }
             else {
-                this.dialog.close(false);
+                this.dialog.close(animate);
             }
         }
     }
 
+    _updateScreenNotification(animate) {
+        this._updateScreenNotificationAsync(animate);
+    }
+
     _updateScreenShieldNotification() {
         if (this.mode == ExtensionMode.RESTRICTED) {
             if (!(this.notification &&
@@ -373,17 +399,17 @@ var PomodoroExtension = class {
         let timerStateDuration = this.timer.getStateDuration();
         let isPaused = this.timer.isPaused();
 
-        if (this._isPaused != isPaused || this._timerState != timerState) {
+        if (this._isPaused !== isPaused || this._timerState !== timerState) {
             this._isPaused = isPaused;
             this._timerState = timerState;
             this._timerStateDuration = timerStateDuration;
 
             this._updatePresence();
             this._updateNotification();
-            this._updateScreenNotification();
+            this._updateScreenNotification(true);
         }
-        else if (this._timerStateDuration == timerStateDuration) {
-            this._updateScreenNotification();
+        else if (this._timerStateDuration === timerStateDuration) {
+            this._updateScreenNotification(true);
         }
         else {
             this._timerStateDuration = timerStateDuration;
@@ -448,9 +474,11 @@ var PomodoroExtension = class {
     }
 
     _enableScreenNotification() {
+        let animate;
+
         if (!this.dialog) {
             this.dialog = new Dialogs.PomodoroEndDialog(this.timer);
-            this.dialog.connect('opening', 
+            this.dialog.connect('opening',
                 () => {
                     try {
                         if (Main.messageTray._notification) {
@@ -477,15 +505,43 @@ var PomodoroExtension = class {
                 () => {
                     this.dialog = null;
                 });
+
+            animate = false;
+        }
+        else {
+            animate = true;
         }
 
-        this._updateScreenNotification();
+        this._updateScreenNotification(animate);
     }
 
     _disableScreenNotification() {
         this._destroyScreenNotification();
     }
 
+    _enableScreenShieldWidget() {
+        if (!this._notificationsBoxPatch) {
+            const extension = this;
+            const patch = new Utils.Patch(UnlockDialog.NotificationsBox.prototype, {
+                _wakeUpScreenForSource(source, notification) {
+                    if (source !== extension.notificationSource) {
+                        return patch.initial._wakeUpScreenForSource.bind(this)(source, notification);
+                    }
+                }
+            });
+
+            this._notificationsBoxPatch = patch;
+            this._notificationsBoxPatch.apply();
+        }
+    }
+
+    _disableScreenShieldWidget() {
+        if (this._notificationsBoxPatch) {
+            this._notificationsBoxPatch.revert();
+            this._notificationsBoxPatch = null;
+        }
+    }
+
     _destroyPresence() {
         if (this.presence) {
             this.presence.destroy();
@@ -534,6 +590,7 @@ var PomodoroExtension = class {
         this._destroying = true;
 
         this._disableKeybinding();
+        this._disableScreenShieldWidget();
 
         this._destroyPresence();
         this._destroyIndicator();
